==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/communication/kotlin/SuppressionList.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.communication.kotlin

import com.pulumi.azurenative.communication.kotlin.outputs.SystemDataResponse
import com.pulumi.azurenative.communication.kotlin.outputs.SystemDataResponse.Companion.toKotlin
import com.pulumi.core.Output
import com.pulumi.kotlin.KotlinCustomResource
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.ResourceMapper
import com.pulumi.kotlin.options.CustomResourceOptions
import com.pulumi.kotlin.options.CustomResourceOptionsBuilder
import com.pulumi.resources.Resource
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit

/**
 * Builder for [SuppressionList].
 */
@PulumiTagMarker
public class SuppressionListResourceBuilder internal constructor() {
    public var name: String? = null

    public var args: SuppressionListArgs = SuppressionListArgs()

    public var opts: CustomResourceOptions = CustomResourceOptions()

    /**
     * @param name The _unique_ name of the resulting resource.
     */
    public fun name(`value`: String) {
        this.name = value
    }

    /**
     * @param block The arguments to use to populate this resource's properties.
     */
    public suspend fun args(block: suspend SuppressionListArgsBuilder.() -> Unit) {
        val builder = SuppressionListArgsBuilder()
        block(builder)
        this.args = builder.build()
    }

    /**
     * @param block A bag of options that control this resource's behavior.
     */
    public suspend fun opts(block: suspend CustomResourceOptionsBuilder.() -> Unit) {
        this.opts = com.pulumi.kotlin.options.opts(block)
    }

    internal fun build(): SuppressionList {
        val builtJavaResource =
            com.pulumi.azurenative.communication.SuppressionList(
                this.name,
                this.args.toJava(),
                this.opts.toJava(),
            )
        return SuppressionList(builtJavaResource)
    }
}

/**
 * A class representing a SuppressionList resource.
 * Azure REST API version: 2023-06-01-preview.
 * ## Example Usage
 * ### CreateOrUpdate SuppressionLists resource.
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var suppressionList = new AzureNative.Communication.SuppressionList("suppressionList", new()
 *     {
 *         DomainName = "contoso.com",
 *         EmailServiceName = "contosoEmailService",
 *         ListName = "contosoNewsAlerts",
 *         ResourceGroupName = "contosoResourceGroup",
 *         SuppressionListName = "aaaa1111-bbbb-2222-3333-aaaa11112222",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/communication/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := communication.NewSuppressionList(ctx, "suppressionList", &communication.SuppressionListArgs{
 * 			DomainName:          pulumi.String("contoso.com"),
 * 			EmailServiceName:    pulumi.String("contosoEmailService"),
 * 			ListName:            pulumi.String("contosoNewsAlerts"),
 * 			ResourceGroupName:   pulumi.String("contosoResourceGroup"),
 * 			SuppressionListName: pulumi.String("aaaa1111-bbbb-2222-3333-aaaa11112222"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.communication.SuppressionList;
 * import com.pulumi.azurenative.communication.SuppressionListArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var suppressionList = new SuppressionList("suppressionList", SuppressionListArgs.builder()
 *             .domainName("contoso.com")
 *             .emailServiceName("contosoEmailService")
 *             .listName("contosoNewsAlerts")
 *             .resourceGroupName("contosoResourceGroup")
 *             .suppressionListName("aaaa1111-bbbb-2222-3333-aaaa11112222")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:communication:SuppressionList aaaa1111-bbbb-2222-3333-aaaa11112222 /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Communication/emailServices/{emailServiceName}/domains/{domainName}/suppressionLists/{suppressionListName}
 * ```
 */
public class SuppressionList internal constructor(
    override val javaResource: com.pulumi.azurenative.communication.SuppressionList,
) : KotlinCustomResource(javaResource, SuppressionListMapper) {
    /**
     * The date the resource was created.
     */
    public val createdTimeStamp: Output<String>
        get() = javaResource.createdTimeStamp().applyValue({ args0 -> args0 })

    /**
     * The location where the SuppressionListAddress data is stored at rest. This value is inherited from the parent Domains resource.
     */
    public val dataLocation: Output<String>
        get() = javaResource.dataLocation().applyValue({ args0 -> args0 })

    /**
     * The date the resource was last updated.
     */
    public val lastUpdatedTimeStamp: Output<String>
        get() = javaResource.lastUpdatedTimeStamp().applyValue({ args0 -> args0 })

    /**
     * The the name of the suppression list. This value must match one of the valid sender usernames of the sending domain.
     */
    public val listName: Output<String>?
        get() = javaResource.listName().applyValue({ args0 -> args0.map({ args0 -> args0 }).orElse(null) })

    /**
     * The name of the resource
     */
    public val name: Output<String>
        get() = javaResource.name().applyValue({ args0 -> args0 })

    /**
     * Azure Resource Manager metadata containing createdBy and modifiedBy information.
     */
    public val systemData: Output<SystemDataResponse>
        get() = javaResource.systemData().applyValue({ args0 -> args0.let({ args0 -> toKotlin(args0) }) })

    /**
     * The type of the resource. E.g. "Microsoft.Compute/virtualMachines" or "Microsoft.Storage/storageAccounts"
     */
    public val type: Output<String>
        get() = javaResource.type().applyValue({ args0 -> args0 })
}

public object SuppressionListMapper : ResourceMapper<SuppressionList> {
    override fun supportsMappingOfType(javaResource: Resource): Boolean =
        com.pulumi.azurenative.communication.SuppressionList::class == javaResource::class

    override fun map(javaResource: Resource): SuppressionList = SuppressionList(
        javaResource as
            com.pulumi.azurenative.communication.SuppressionList,
    )
}

/**
 * @see [SuppressionList].
 * @param name The _unique_ name of the resulting resource.
 * @param block Builder for [SuppressionList].
 */
public suspend fun suppressionList(
    name: String,
    block: suspend SuppressionListResourceBuilder.() -> Unit,
): SuppressionList {
    val builder = SuppressionListResourceBuilder()
    builder.name(name)
    block(builder)
    return builder.build()
}

/**
 * @see [SuppressionList].
 * @param name The _unique_ name of the resulting resource.
 */
public fun suppressionList(name: String): SuppressionList {
    val builder = SuppressionListResourceBuilder()
    builder.name(name)
    return builder.build()
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/communication/kotlin/SuppressionList.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.communication.kotlin

import com.pulumi.azurenative.communication.kotlin.outputs.SystemDataResponse
import com.pulumi.azurenative.communication.kotlin.outputs.SystemDataResponse.Companion.toKotlin
import com.pulumi.core.Output
import com.pulumi.kotlin.KotlinCustomResource
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.ResourceMapper
import com.pulumi.kotlin.options.CustomResourceOptions
import com.pulumi.kotlin.options.CustomResourceOptionsBuilder
import com.pulumi.resources.Resource
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit

/**
 * Builder for [SuppressionList].
 */
@PulumiTagMarker
public class SuppressionListResourceBuilder internal constructor() {
    public var name: String? = null

    public var args: SuppressionListArgs = SuppressionListArgs()

    public var opts: CustomResourceOptions = CustomResourceOptions()

    /**
     * @param name The _unique_ name of the resulting resource.
     */
    public fun name(`value`: String) {
        this.name = value
    }

    /**
     * @param block The arguments to use to populate this resource's properties.
     */
    public suspend fun args(block: suspend SuppressionListArgsBuilder.() -> Unit) {
        val builder = SuppressionListArgsBuilder()
        block(builder)
        this.args = builder.build()
    }

    /**
     * @param block A bag of options that control this resource's behavior.
     */
    public suspend fun opts(block: suspend CustomResourceOptionsBuilder.() -> Unit) {
        this.opts = com.pulumi.kotlin.options.CustomResourceOptions.opts(block)
    }

    internal fun build(): SuppressionList {
        val builtJavaResource =
            com.pulumi.azurenative.communication.SuppressionList(
                this.name,
                this.args.toJava(),
                this.opts.toJava(),
            )
        return SuppressionList(builtJavaResource)
    }
}

/**
 * A class representing a SuppressionList resource.
 * Azure REST API version: 2023-06-01-preview.
 * ## Example Usage
 * ### CreateOrUpdate SuppressionLists resource.
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var suppressionList = new AzureNative.Communication.SuppressionList("suppressionList", new()
 *     {
 *         DomainName = "contoso.com",
 *         EmailServiceName = "contosoEmailService",
 *         ListName = "contosoNewsAlerts",
 *         ResourceGroupName = "contosoResourceGroup",
 *         SuppressionListName = "aaaa1111-bbbb-2222-3333-aaaa11112222",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/communication/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := communication.NewSuppressionList(ctx, "suppressionList", &communication.SuppressionListArgs{
 * 			DomainName:          pulumi.String("contoso.com"),
 * 			EmailServiceName:    pulumi.String("contosoEmailService"),
 * 			ListName:            pulumi.String("contosoNewsAlerts"),
 * 			ResourceGroupName:   pulumi.String("contosoResourceGroup"),
 * 			SuppressionListName: pulumi.String("aaaa1111-bbbb-2222-3333-aaaa11112222"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.communication.SuppressionList;
 * import com.pulumi.azurenative.communication.SuppressionListArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var suppressionList = new SuppressionList("suppressionList", SuppressionListArgs.builder()
 *             .domainName("contoso.com")
 *             .emailServiceName("contosoEmailService")
 *             .listName("contosoNewsAlerts")
 *             .resourceGroupName("contosoResourceGroup")
 *             .suppressionListName("aaaa1111-bbbb-2222-3333-aaaa11112222")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:communication:SuppressionList aaaa1111-bbbb-2222-3333-aaaa11112222 /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Communication/emailServices/{emailServiceName}/domains/{domainName}/suppressionLists/{suppressionListName}
 * ```
 */
public class SuppressionList internal constructor(
    override val javaResource: com.pulumi.azurenative.communication.SuppressionList,
) : KotlinCustomResource(javaResource, SuppressionListMapper) {
    /**
     * The date the resource was created.
     */
    public val createdTimeStamp: Output<String>
        get() = javaResource.createdTimeStamp().applyValue({ args0 -> args0 })

    /**
     * The location where the SuppressionListAddress data is stored at rest. This value is inherited from the parent Domains resource.
     */
    public val dataLocation: Output<String>
        get() = javaResource.dataLocation().applyValue({ args0 -> args0 })

    /**
     * The date the resource was last updated.
     */
    public val lastUpdatedTimeStamp: Output<String>
        get() = javaResource.lastUpdatedTimeStamp().applyValue({ args0 -> args0 })

    /**
     * The the name of the suppression list. This value must match one of the valid sender usernames of the sending domain.
     */
    public val listName: Output<String>?
        get() = javaResource.listName().applyValue({ args0 -> args0.map({ args0 -> args0 }).orElse(null) })

    /**
     * The name of the resource
     */
    public val name: Output<String>
        get() = javaResource.name().applyValue({ args0 -> args0 })

    /**
     * Azure Resource Manager metadata containing createdBy and modifiedBy information.
     */
    public val systemData: Output<SystemDataResponse>
        get() = javaResource.systemData().applyValue({ args0 -> args0.let({ args0 -> toKotlin(args0) }) })

    /**
     * The type of the resource. E.g. "Microsoft.Compute/virtualMachines" or "Microsoft.Storage/storageAccounts"
     */
    public val type: Output<String>
        get() = javaResource.type().applyValue({ args0 -> args0 })
}

public object SuppressionListMapper : ResourceMapper<SuppressionList> {
    override fun supportsMappingOfType(javaResource: Resource): Boolean =
        com.pulumi.azurenative.communication.SuppressionList::class == javaResource::class

    override fun map(javaResource: Resource): SuppressionList = SuppressionList(
        javaResource as
            com.pulumi.azurenative.communication.SuppressionList,
    )
}

/**
 * @see [SuppressionList].
 * @param name The _unique_ name of the resulting resource.
 * @param block Builder for [SuppressionList].
 */
public suspend fun suppressionList(
    name: String,
    block: suspend SuppressionListResourceBuilder.() -> Unit,
): SuppressionList {
    val builder = SuppressionListResourceBuilder()
    builder.name(name)
    block(builder)
    return builder.build()
}

/**
 * @see [SuppressionList].
 * @param name The _unique_ name of the resulting resource.
 */
public fun suppressionList(name: String): SuppressionList {
    val builder = SuppressionListResourceBuilder()
    builder.name(name)
    return builder.build()
}
